# -----------------------------------------------------------------------------
# Copyright (c) 2025, Oracle and/or its affiliates.
#
# Licensed under the Universal Permissive License v 1.0 as shown at
# http://oss.oracle.com/licenses/upl.
# -----------------------------------------------------------------------------

import os

import select_ai

user = os.getenv("SELECT_AI_USER")
password = os.getenv("SELECT_AI_PASSWORD")
dsn = os.getenv("SELECT_AI_DB_CONNECT_STRING")

# This example shows how to have a context-aware
# conversation


def main():
    select_ai.connect(user=user, password=password, dsn=dsn)
    profile = select_ai.Profile(profile_name="oci_ai_profile")
    conversation_attributes = select_ai.ConversationAttributes(
        title="History of Science",
        description="LLM's understanding of history of science",
    )
    conversation = select_ai.Conversation(attributes=conversation_attributes)
    with profile.chat_session(
        conversation=conversation, delete=True
    ) as session:
        print(
            "Conversation ID for this session is:",
            conversation.conversation_id,
        )
        response = session.chat(
            prompt="What is importance of history of science ?"
        )
        print(response)
        response = session.chat(
            prompt="Elaborate more on 'Learning from past mistakes'"
        )
        print(response)


if __name__ == "__main__":
    main()
